@@ -1,11 +1,19 @@
 #NCA-->GLM
+###
+### NCAdata(), NCAcsv() -> for ;NCA only' data input;
+### BANOVAdata(), BANOVAcsv() -> for 'statistical analysis only' data input;
+### NCA.BANOVAdata(), NCA.BANOVAcsv() for 'NCA -> statistical analysis' data input.
+###
 NCA.BANOVAdata<-function(replicated=FALSE, parallel=FALSE, multiple=FALSE)
 {
 cat("\n")
+
+Fname<-Fname
+
 file.menu <- c("Input/edit data from keyboard",
                "Import data file with .csv format",
                "Load data File with .RData format",
-               "Back to NCA --> Statistical analysis",
+               "Back to the top menu",
                "Quit")
 cat("\n")
 
@@ -70,26 +78,33 @@ cat("\n")
         else{
            saveRDS(TotalSingledata,TotalSinglename)
           }
-        if(parallel){
-            if(multiple){
-            return(MultipleParaNCA.MIXanalyze(TotalSingledata))
-            }
-            else{
-            return(ParaNCA.MIXanalyze(TotalSingledata))
-             }
+          
+          Fname<<-TotalSinglename
+          ###
+          ### now starting checking if the dataset is incomplete data (icd); if it is then stop running;
+          ### if it is not, then go to analysis (see icd.check()). 'TotalSingledata' is the first dataset
+          ### generated by bear once the raw data has been loaded; same as for NCAcsv().
+          ###
+          if(parallel){
+             if(multiple){
+                 icd.check(TotalSingledata,parallel=TRUE,multiple=TRUE,replicated=FALSE,NCA.only=FALSE)
+               }
+              else{
+                 icd.check(TotalSingledata,parallel=TRUE,multiple=FALSE,replicated=FALSE,NCA.only=FALSE)
+               }
            }
-           else{ 
-         if(replicated){
-              return(RepNCA.MIXanalyze(TotalSingledata))
+          else{ 
+            if (replicated){
+                 icd.check(TotalSingledata,parallel=FALSE,multiple=FALSE,replicated=TRUE,NCA.only=FALSE)
              }
            else{
               if(multiple){
-              return(MultipleNCA.BANOVAanalyze(TotalSingledata))
-              }
-              else{
-              return(NCA.BANOVAanalyze(TotalSingledata))
-              }
-           }  
+                 icd.check(TotalSingledata,parallel=FALSE,multiple=TRUE,replicated=FALSE,NCA.only=FALSE)
+                  }
+               else{ 
+                 icd.check(TotalSingledata,parallel=FALSE,multiple=FALSE,replicated=FALSE,NCA.only=FALSE)
+               } 
+            }  
          }
        } 
 else {
@@ -127,8 +142,9 @@ else {
 ##     TotalSinglename <-readline() 
 ##     TotalSinglename<-paste(TotalSinglename,".RData",sep="")
 ##     load(TotalSinglename)
-     TotalSingledata<-readRDS(file.choose())
+     TotalSingledata<-readRDS(xx<-file.choose())
      TotalSingledata<-edit(TotalSingledata)
+     Fname<<-basename(xx)
      ### TotalSingledata<- na.omit(TotalSingledata)    ### for 2.6.1 
      if(parallel){
       colnames(TotalSingledata)<-list("subj", "drug","time", "conc")
@@ -144,53 +160,37 @@ else {
      cat("\n\n")
      show(TotalSingledata)
      cat("\n\n")
-        if(parallel){
-            if(multiple){
-            return(MultipleParaNCA.MIXanalyze(TotalSingledata))
-            }
-            else{
-            return(ParaNCA.MIXanalyze(TotalSingledata))
-             }
+          ###
+          ### now starting checking if the dataset is incomplete data (icd); if it is then stop running;
+          ### if it is not, then go to analysis (see icd.check()). 'TotalSingledata' is the first dataset
+          ### generated by bear once the raw data has been loaded; same as for NCAcsv().
+          ###
+          if(parallel){
+             if(multiple){
+                 icd.check(TotalSingledata,parallel=TRUE,multiple=TRUE,replicated=FALSE,NCA.only=FALSE)
+               }
+              else{
+                 icd.check(TotalSingledata,parallel=TRUE,multiple=FALSE,replicated=FALSE,NCA.only=FALSE)
+               }
            }
-           else{ 
-         if(replicated){
-              return(RepNCA.MIXanalyze(TotalSingledata))
+          else{ 
+            if (replicated){
+                 icd.check(TotalSingledata,parallel=FALSE,multiple=FALSE,replicated=TRUE,NCA.only=FALSE)
              }
            else{
               if(multiple){
-              return(MultipleNCA.BANOVAanalyze(TotalSingledata))
-              }
-              else{
-              return(NCA.BANOVAanalyze(TotalSingledata))
-              }
-             }  
+                 icd.check(TotalSingledata,parallel=FALSE,multiple=TRUE,replicated=FALSE,NCA.only=FALSE)
+                  }
+               else{ 
+                 icd.check(TotalSingledata,parallel=FALSE,multiple=FALSE,replicated=FALSE,NCA.only=FALSE)
+               } 
+            }  
          }
       }
-
   else {
   if (pick == 4){
-     cat("\n\n")
-      if(parallel){
-       if(multiple){
-        MultipleParaNCA.MIXmenu()
-        }
-       else{     
-        ParaNCA.MIXmenu()
-         }  
-       }
-      else{  
-      if (replicated){
-              RepNCA.MIXmenu()
-             }
-       else{
-       if(multiple){
-              return(MultipleNCA.BANOVAmenu())
-              }
-              else{
-              return( NCA.BANOVAmenu())
-               }
-             }
-          }
+     graphics.off();cat("\n\n")
+     go2menu()
         }  
   else {
   if (pick == 5){
