@@ -1022,7 +1022,8 @@ RepTTTAICoutput(sumindexR, sumindexT,R.split,T.split,keindex_ref,keindex_test,Do
 RepNCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis)
  if (Demo){
          #Demo=TRUE, MIX=FALSE
-         Repmenu()
+         ### Repmenu()
+         cat("\n\n");go2menu()
         }
        else {
          if(MIX){
@@ -1044,7 +1045,8 @@ else{
         MultipleParaNCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis,TlastD)
           if (Demo){
           #Demo=TRUE, BANOVA=FALSE
-          MultipleParamenu()
+          ### MultipleParamenu()
+          cat("\n\n");go2menu()
           }
            else {
              if(MIX){
@@ -1062,7 +1064,8 @@ else{
       ParaNCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis) 
       if (Demo){
          #Demo=TRUE, MIX=FALSE
-         Paramenu() 
+         ### Paramenu() 
+         cat("\n\n");go2menu()
         }
        else {
          if(MIX){
@@ -1084,7 +1087,8 @@ else{
         MultipleNCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis,TlastD)
           if (Demo){
           #Demo=TRUE, BANOVA=FALSE
-          MultipleNCAmenu()
+          ### MultipleNCAmenu()
+          cat("\n\n");go2menu()
           }
            else {
              if(BANOVA){
@@ -1101,8 +1105,9 @@ else{
         TTTAICoutput(sumindexR, sumindexT,R.split, T.split,keindex_ref,keindex_test,Dose,TotalData )
         NCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis)
       if (Demo){
-      #Demo=TRUE, BANOVA=FALSE
-          NCAmenu()
+         #Demo=TRUE, BANOVA=FALSE
+         ### NCAmenu()
+         cat("\n\n");go2menu()
       }
       else {
         if(BANOVA){
