@@ -1,4 +1,4 @@
 TTToutput<-function(sumindexR, sumindexT, R.split, T.split, keindex_ref, keindex_test, Dose, TotalData){
 NCAoutput(sumindexR, sumindexT, R.split, T.split, keindex_ref, keindex_test, Dose, TotalData,
-          NCA=FALSE,ARS=FALSE,TTT=TRUE)
+          NCA=FALSE,ARS=FALSE,TTT=TRUE,aic=FALSE,TTTARS=FALSE,TTTAIC=FALSE)
 }
\ No newline at end of file
