@@ -1027,7 +1027,8 @@ RepAICoutput(sumindexR, sumindexT,R.split,T.split,keindex_ref,keindex_test,Dose,
 RepNCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis)
     if (Demo){
          #Demo=TRUE, MIX=FALSE
-         Repmenu() 
+         ### Repmenu() 
+         cat("\n\n");go2menu()
         }
      else {
          if(MIX){
@@ -1050,7 +1051,8 @@ else{
         MultipleParaNCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis,TlastD)
           if (Demo){
           #Demo=TRUE, BANOVA=FALSE
-          MultipleParamenu()
+          ### MultipleParamenu()
+          cat("\n\n");go2menu()
           }
            else {
              if(MIX){
@@ -1068,7 +1070,8 @@ else{
       ParaNCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis) 
       if (Demo){
          #Demo=TRUE, MIX=FALSE
-         Paramenu() 
+         ### Paramenu() 
+         cat("\n\n");go2menu()
         }
        else {
          if(MIX){
@@ -1090,11 +1093,12 @@ else{
         MultipleNCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis,TlastD)
           if (Demo){
           #Demo=TRUE, BANOVA=FALSE
-          MultipleNCAmenu()
+          ### MultipleNCAmenu()
+          cat("\n\n");go2menu()
           }
            else {
              if(BANOVA){
-            ##Demo=FALSE, BANOVA=TRUE
+             ##Demo=FALSE, BANOVA=TRUE
              ### dev.off()            ### not req.? --YJ
              MultipleBANOVAanalyze(TotalData)
                 }
@@ -1111,7 +1115,8 @@ else{
 
        if (Demo){
         #Demo=TRUE, BANOVA=FALSE
-        NCAmenu()
+        ### NCAmenu()
+        cat("\n\n");go2menu()
         }
         else {
          if(BANOVA){
